<?php

class Theme_Ability {

	var $theme_name = 'Ability';

	function __construct() {

		Add_Action('after_setup_theme', Array($this, 'custom_header_setup'));
		Add_Action('widgets_init', Array($this, 'Load_TextDomain'));
		Add_Action('widgets_init', array($this, 'Register_Menus'));
		Add_Action('wp_enqueue_scripts', Array($this,'scripts_styles'));
		Add_Action('widgets_init', Array($this, 'widgets_init'));
		Add_Action('template_redirect', Array($this, 'content_width'));
		Add_Action('customize_register', Array($this, 'customize_register'));
		Add_Action('customize_preview_init', Array($this, 'customize_preview_js'));
		Add_Action('wp_dashboard_setup', Array($this, 'Add_Dashboard_Meta_Box'));
		Add_Action('admin_enqueue_scripts', Array($this, 'Add_Admin_Menu_Style'));

		Add_Filter('wp_title', Array($this,'wp_title'), 10, 2);
		Add_Filter('wp_page_menu_args', Array($this, 'page_menu_args'));
		Add_Filter('body_class', Array($this,'body_class'));
		Add_Filter('theme_mod_header_image', Array($this, 'Filter_Banner_Image'));
		Add_Filter('excerpt_more', Array($this,'custom_excerpt_more'));
		Add_Filter('admin_footer_text', Array($this, 'Custom_Admin_Footer_Text'));
		Add_Filter('use_default_gallery_style', '__return_false');
		Add_Filter('shortcode_atts_gallery', Array($this, 'Filter_Shortcode_Atts_Gallery'));
		Add_Filter('excerpt_length', Array($this, 'Filter_Excerpt_Length'));
		Add_Filter('the_title', Array($this, 'Filter_The_Title'));

		Add_Editor_Style();

		Add_Theme_Support('automatic-feed-links');
		Add_Theme_Support('custom-background', Array('default-color' => 'e6e6e6'));
		Add_Theme_Support('post-thumbnails' );

		Set_Post_Thumbnail_Size( 624, 9999 );
		//Add_Image_Size('header-image', get_custom_header()->width, get_custom_header()->height, True);
		Add_Image_Size('header-image', 1040, 300, True);
		Add_Image_Size('preview-thumb', 200, 200, True);
		Add_Image_Size('preview-gallery', 300, 250, True);
	}

	function Filter_The_Title($title){
		If (Empty($title))
			return SPrintF($this->t('%s from %s'), __('Post'), Get_The_Date());
		Else
			return $title;
	}

	function Filter_Excerpt_Length($lenght){
		Return 40;
	}

	function Filter_Shortcode_Atts_Gallery($attributes){
		$attributes['size'] = 'preview-gallery';
		return $attributes;
	}

	function Add_Admin_Menu_Style(){
		WP_Register_Style('ability_adminmenu_style', get_template_directory_uri().'/css/style-adminmenu.css', false, '1.0');
		WP_Enqueue_Style('ability_adminmenu_style');
	}

	function Add_Dashboard_Meta_Box(){
		Add_Meta_Box(
			'dashboard-support-widget',
			$this->t('WordPress Support'),
			Array($this, 'Print_Dashboard_Support_Widget'),
			'dashboard',
			'normal',
			'high'
		);
	}

	function Print_Dashboard_Support_Widget() {
		?>
		<div class="support-widget" style="overflow: hidden">
			<img src="<?php echo get_template_directory_uri().'/images/ring.png' ?>" alt="<?php echo $this->t('WordPress Support') ?>" title="<?php echo $this->t('WordPress Support') ?>" class="alignleft">
			<div>
				<?php PrintF($this->t('Thank you for using our WordPress Theme <i>%1$s</i>. If you need support for this theme or if you need help with your WordPress website feel free to contact us. Among other services we provide:'), $this->theme_name) ?>
				<ul>
					<li><?php echo $this->t('Install and set up your WordPress website') ?></li>
					<li><?php echo $this->t('Create, install or modify plugins and extensions') ?></li>
					<li><?php echo $this->t('Customize the theme according to your wishes') ?></li>
					<li><?php echo $this->t('Change and create new page templates') ?></li>
				</ul>
			</div>
			<?php Echo SPrintF('<a href="%1$s" title="%2$s" class="button-primary" target="_blank">%3$s</a>',
			$this->t('http://ulrikeseddig.de/en/wordpress-services/'),
			$this->t('Contact Ulrike Seddig WordPress Consulting'),
			$this->t('Get in touch')) ?>
		</div>
		<?php
	}

	function Custom_Admin_Footer_Text($footer_text){
		$footer_text .= SPrintF(' | '.$this->t('Theme by ').'<a href="%1$s" target="_blank" title="%2$s">Ulrike Seddig</a>'.' | <a href="%3$s" target="_blank" title="%4$s">%5$s</a>',
			$this->t('http://ulrikeseddig.de/en/'),
			$this->t('Ulrike Seddig WordPress Consulting'),
			$this->t('http://ulrikeseddig.de/en/wordpress-themes/ability/'),
			$this->t('WordPress Theme Ability'),
			$this->t('Help')
			);
		return $footer_text;
	}

	function Locate_File_Uri ($file){
    If (SubStr($file, 0, 1) != '/')
      $file = '/' . $file;
		If (File_Exists(get_stylesheet_directory() . $file))
			return get_stylesheet_directory_uri() . $file;
		ElseIf (File_Exists(get_template_directory() . $file))
			return get_template_directory_uri() . $file;
		Else
      return False;
	}

	function Load_TextDomain(){
    $locale = Apply_Filters( 'theme_locale', get_locale(), __CLASS__ );
    load_textdomain (__CLASS__, DirName(__FILE__).'/language/' . $locale . '.mo');
  }

  function t ($text, $context = ''){
    // Translates the string $text with context $context
    If ($context == '')
      return __ ($text, __CLASS__);
    Else
      return _x ($text, $context, __CLASS__);
  }

	function Register_Menus(){
		register_nav_menu('primary', $this->t('Primary Menu'));
		register_nav_menu('footer', $this->t('Footer Menu'));
	}

	function Filter_Banner_Image($header_image){
		If (is_singular() && has_post_thumbnail()) {
			$featured_image_id = get_post_thumbnail_id();
			$featured_image_url = WP_Get_Attachment_Image_Src($featured_image_id, 'header-image');
			return $featured_image_url[0];
		}
		return $header_image;
	}

	function Custom_Header_Setup() {
		$args = array(
			'default-text-color'     => '444',
			'default-image'          => '',

			'height'                 => 300,
			'width'                  => 1040,
			'max-width'              => 1040,

			'flex-height'            => false,
			'flex-width'             => false,

			'random-default'         => false,

			'wp-head-callback'       => Array($this, 'header_style'),
			'admin-head-callback'    => Array($this, 'admin_header_style'),
			'admin-preview-callback' => Array($this, 'admin_header_image'),
		);

		add_theme_support( 'custom-header', $args );
	}

	function Header_Style() {
		$text_color = get_header_textcolor();
		If ( $text_color == get_theme_support( 'custom-header', 'default-text-color' ) )
			return;
		?>
		<style type="text/css">
		<?php If ( ! display_header_text() ) : ?>
			.site-title,
			.site-description {
				position: absolute !important;
				clip: rect(1px 1px 1px 1px);
				clip: rect(1px, 1px, 1px, 1px);
			}
		<?php Else : ?>
			.site-title a,
			.site-description {
				color: #<?php echo $text_color; ?>;
			}
		<?php Endif; ?>
		</style>
		<?php
	}

	function Admin_Header_Style() {	?>
		<style type="text/css">
		.appearance_page_custom-header #headimg {
			border: none;
		}
		#headimg h1,
		#headimg h2 {
			line-height: 1.6;
			margin: 0;
			padding: 0;
		}
		#headimg h1 {
			font-size: 30px;
		}
		#headimg h1 a {
			color: #515151;
			text-decoration: none;
		}
		#headimg h1 a:hover {
			color: #21759b;
		}
		#headimg h2 {
			color: #757575;
			font: normal 13px/1.8 "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", sans-serif;
			margin-bottom: 24px;
		}
		#headimg img {
			max-width: <?php echo get_theme_support( 'custom-header', 'max-width' ); ?>px;
		}
		</style>
	<?php
	}

	function Admin_Header_Image() { ?>
		<div id="headimg">
			<?php
			if ( ! display_header_text() )
				$style = ' style="display:none;"';
			else
				$style = ' style="color:#' . get_header_textcolor() . ';"';
			?>
			<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
			<h2 id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></h2>
			<?php $header_image = get_header_image();
			if ( ! empty( $header_image ) ) : ?>
				<img src="<?php echo esc_url( $header_image ); ?>" class="header-image" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
			<?php endif; ?>
		</div>
	<?php }

	function Scripts_Styles() {
		global $wp_styles;

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

		wp_enqueue_script( 'ability-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );

		if ( 'off' !== $this->t('on', 'Open Sans font: on or off')) {

			$subsets = 'latin,latin-ext';

			$subset = $this->t('no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)');

			if ( 'cyrillic' == $subset )
				$subsets .= ',cyrillic,cyrillic-ext';

			elseif ( 'greek' == $subset )
				$subsets .= ',greek,greek-ext';

			elseif ( 'vietnamese' == $subset )
				$subsets .= ',vietnamese';

			$protocol = is_ssl() ? 'https' : 'http';

			$query_args = array(
				'family' => 'Open+Sans:400italic,700italic,400,700',
				'subset' => $subsets,
			);

			wp_enqueue_style( 'ability-fonts', add_query_arg( $query_args, "$protocol://fonts.googleapis.com/css" ), array(), null );
		}

		wp_enqueue_style( 'ability-style', get_stylesheet_uri() );

	}

	function WP_Title( $title, $sep ) {
		global $paged, $page;

		if ( is_feed() )
			return $title;

		// Add the site name.
		$title .= get_bloginfo( 'name' );

		// Add the site description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) )
			$title = "$title $sep $site_description";

		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 )
			$title = "$title $sep " . sprintf( $this->t('Page %s'), max( $paged, $page ) );

		return $title;
	}

	function Page_Menu_Args( $args ) {
		if ( ! isset( $args['show_home'] ) )
			$args['show_home'] = true;
		return $args;
	}

	function Widgets_Init() {
		register_sidebar( array(
			'name' => $this->t('Main Sidebar'),
			'id' => 'sidebar-1',
			'description' => $this->t('Appears on posts and pages except the optional Footer Widget template, which has its own widgets.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );

		register_sidebar( array(
			'name' => $this->t( 'Blog Sidebar'),
			'id' => 'sidebar-2',
			'description' => $this->t('Appears on all archive pages including the blog page.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );

		register_sidebar( array(
			'name' => $this->t( 'Post Sidebar'),
			'id' => 'sidebar-3',
			'description' => $this->t('Appears only on single view of posts.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );

		register_sidebar( array(
			'name' => $this->t('First Footer Widget Area'),
			'id' => 'sidebar-4',
			'description' => $this->t('Appears below the main content when using the optional Footer Widget template.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );

		register_sidebar( array(
			'name' => $this->t('Second Footer Widget Area'),
			'id' => 'sidebar-5',
			'description' => $this->t('Appears below the main content when using the optional Footer Widget template.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );

		register_sidebar( array(
			'name' => $this->t('Third Footer Widget Area'),
			'id' => 'sidebar-6',
			'description' => $this->t('Appears below the main content when using the optional Footer Widget template.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );

		register_sidebar( array(
			'name' => $this->t('Fourth Footer Widget Area'),
			'id' => 'sidebar-7',
			'description' => $this->t('Appears below the main content when using the optional Footer Widget template.'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
	}

	function Content_Nav( $html_id ) {
		global $wp_query;

		$html_id = esc_attr( $html_id );

		if ( $wp_query->max_num_pages > 1 ) : ?>
			<nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
				<h3 class="assistive-text"><?php echo $this->t('Post navigation'); ?></h3>
				<div class="nav-previous"><?php next_posts_link( $this->t('Older posts')); ?></div>
				<div class="nav-next"><?php previous_posts_link( $this->t('Newer posts')); ?></div>
			</nav><!-- #<?php echo $html_id; ?> .navigation -->
		<?php endif;
	}

	function Comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
			// Display trackbacks differently than normal comments.
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
			<p><?php $this->t('Pingback:'); ?> <?php comment_author_link(); ?> <?php edit_comment_link( $this->t('(Edit)'), '<span class="edit-link">', '</span>' ); ?></p>
		<?php
				break;
			default :
			// Proceed with normal comments.
			global $post;
		?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<article id="comment-<?php comment_ID(); ?>" class="comment">
				<header class="comment-meta comment-author vcard">
					<?php
						echo get_avatar( $comment, 44 );
						printf( '<cite class="fn">%1$s %2$s</cite>',
							get_comment_author_link(),
							// If current post author is also comment author, make it known visually.
							( $comment->user_id === $post->post_author ) ? '<span> ' . $this->t( 'Post author') . '</span>' : ''
						);
						printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( $this->t('%1$s at %2$s'), get_comment_date(), get_comment_time() )
						);
					?>
				</header><!-- .comment-meta -->

				<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation"><?php $this->t('Your comment is awaiting moderation.'); ?></p>
				<?php endif; ?>

				<section class="comment-content comment">
					<?php comment_text(); ?>
					<?php edit_comment_link( $this->t('Edit'), '<p class="edit-link">', '</p>' ); ?>
				</section><!-- .comment-content -->

				<div class="reply">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => $this->t('Reply'), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div><!-- .reply -->
			</article><!-- #comment-## -->
		<?php
			break;
		endswitch; // end comment_type check
	}

	function Entry_Meta() {
		// Translators: used between list items, there is a space after the comma.
		$categories_list = get_the_category_list( $this->t(', '));

		// Translators: used between list items, there is a space after the comma.
		$tag_list = get_the_tag_list( '', $this->t(', '));

		$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
			esc_url( get_permalink() ),
			esc_attr( get_the_time() ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);

		$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_attr( sprintf( $this->t('View all posts by %s'), get_the_author() ) ),
			get_the_author()
		);

		// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
		if ( $tag_list ) {
			$utility_text = $this->t('This entry was posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.');
		} elseif ( $categories_list ) {
			$utility_text = $this->t('This entry was posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.');
		} else {
			$utility_text = $this->t('This entry was posted on %3$s<span class="by-author"> by %4$s</span>.');
		}

		printf(
			$utility_text,
			$categories_list,
			$tag_list,
			$date,
			$author
		);
	}

	function Body_Class( $classes ) {
		$background_color = get_background_color();

		if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/full-width.php' ) )
			$classes[] = 'full-width';

		if ( is_page_template( 'page-templates/front-page.php' ) ) {
			$classes[] = 'template-front-page';
			if ( has_post_thumbnail() )
				$classes[] = 'has-post-thumbnail';
			if ( is_active_sidebar( 'sidebar-3' ) && is_active_sidebar( 'sidebar-4' ) )
				$classes[] = 'two-sidebars';
		}

		if ( empty( $background_color ) )
			$classes[] = 'custom-background-empty';
		elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) )
			$classes[] = 'custom-background-white';

		// Enable custom font class only if the font CSS is queued to load.
		if ( wp_style_is( 'ability-fonts', 'queue' ) )
			$classes[] = 'custom-font-enabled';

		if ( ! is_multi_author() )
			$classes[] = 'single-author';

		return $classes;
	}

	function Content_Width() {
		if ( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
			global $content_width;
			$content_width = 960;
		}
	}

	function Customize_Register( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	}

	function Customize_Preview_JS() {
		wp_enqueue_script( 'ability-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20120827', true );
	}

	function Custom_Excerpt_More( $more ) {
		return '...';
	}

}

$THEME = New Theme_Ability;